summaryrefslogtreecommitdiff
path: root/capture_info.h
diff options
context:
space:
mode:
Diffstat (limited to 'capture_info.h')
-rw-r--r--capture_info.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/capture_info.h b/capture_info.h
index 3e5845ac6c..286dce12c0 100644
--- a/capture_info.h
+++ b/capture_info.h
@@ -43,8 +43,8 @@ extern void capture_info_open(capture_session *cap_session);
/* new file arrived - (eventually close old wtap), open wtap */
extern gboolean capture_info_new_file(const char *new_filename);
-/* new packets arrived - read from wtap, count */
-extern void capture_info_new_packets(int to_read);
+/* new records arrived - read from wtap, count */
+extern void capture_info_new_records(int to_read);
/* close the info - close wtap, destroy dialog */
extern void capture_info_close(void);